SCIproj-package: SCIproj package

SCIproj-packageR Documentation

SCIproj package

Description

Generic template for research projects structured as R packages. This package works as a template for new research projects, under the idea of having everything (data, R scripts, functions and manuscripts) contained in the same package to promote reproducible research.

Details

For detailed steps on how to use the package see https://github.com/saskiaotto/SCIproj/blob/main/README.md.

Author(s)

Saskia A. Otto

See Also

Useful links:


SCIproj documentation built on March 18, 2026, 5:07 p.m.