| clean_pkg_name | R Documentation |
Converts underscores and hyphens to dots and removes other invalid characters. R package names may only contain letters, numbers, and dots, must start with a letter, and must not end with a dot.
clean_pkg_name(name)
name |
Character. The directory name to clean. |
A valid R package name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.