| SCIproj-package | R Documentation |
Generic template for research projects structured as R packages. This package works as a template for new research projects, under the idea of having everything (data, R scripts, functions and manuscripts) contained in the same package to promote reproducible research.
For detailed steps on how to use the package see https://github.com/saskiaotto/SCIproj/blob/main/README.md.
Saskia A. Otto
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.